verify

Function verify 

pub fn verify(key: &SigningKey, jws: &str) -> Result<()>
Verify a compact ES256 JWS against key’s public half.

Used by the tests and available for verifying anything we minted; the PDS verifies our assertions itself via the published JWKS.