pub async fn send_with_dpop(
client: &Client,
pool: &SqlitePool,
request: &DpopRequest<'_>,
) -> Result<PostOutcome>Expand description
Send a request with a DPoP proof, retrying once if the server demands a
nonce and Retry permits it.
pub async fn send_with_dpop(
client: &Client,
pool: &SqlitePool,
request: &DpopRequest<'_>,
) -> Result<PostOutcome>Send a request with a DPoP proof, retrying once if the server demands a
nonce and Retry permits it.